## Employing the agricultural classification and estimation service (ACES) for mapping smallholder rice farms in Bhutan

This repo contains the workflow for our [First Paper](https://www.frontiersin.org/articles/10.3389/fenvs.2023.1137835/full) of the Random Forest methodologies.  All the methods are implemented using Google Earth Engine (GEE) using JavaScript. In the future, we look to migrate and integrate those scripts to this repository.
